package com.samelement.iot_notification.service;

import android.app.NotificationManager;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.util.Log;

import androidx.preference.PreferenceManager;
import androidx.work.Constraints;
import androidx.work.ExistingWorkPolicy;
import androidx.work.NetworkType;
import androidx.work.OneTimeWorkRequest;
import androidx.work.WorkManager;

import com.samelement.iot_notification.screen.IntentKey;
import com.samelement.iot_notification.service.worker.RestartServiceWorker;

public class RestartServiceReceiver extends BroadcastReceiver {
    private final String TAG = RestartServiceReceiver.class.getName();

    @Override
    public void onReceive(Context context, Intent intent) {
        String action = intent.getAction();
        if (action != null) {
            if (action.equals(IntentKey.RESTART_ACTION)) {
                SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(context);
                int notificationId = prefs.getInt(IntentKey.KEY_NOTIF_ID, -1);
                NotificationManager notificationManager = (NotificationManager)
                        context.getSystemService(Context.NOTIFICATION_SERVICE);
                if (notificationManager != null && notificationId >= 0) {
                    notificationManager.cancel(notificationId);
                    try {
                        Constraints constraints = new Constraints.Builder()
                                .setRequiredNetworkType(NetworkType.CONNECTED)
                                .build();

                        OneTimeWorkRequest restartRequest = new OneTimeWorkRequest.Builder(RestartServiceWorker.class)
                                .setConstraints(constraints)
                                .build();

                        WorkManager.getInstance(context).enqueueUniqueWork("requestRestartServiceFromReceiver", ExistingWorkPolicy.REPLACE, restartRequest);
                    } catch (Exception e) {
                        Log.d(TAG, "Error restart action. " + e.getMessage());
                    }
                }


            }
        }
    }
}